import React, { useRef, useState } from "react";
import Header from "./components/Header";
import Footer from "./components/Footer";
import SideBar from "./components/SideBar";
import Accordion from "@/components/UI/accordion/Accordion";
import AccordionItem from "@/components/UI/accordion/components/AccordionItem";
import { FaUserPlus } from "react-icons/fa";
import { TbWorldWww } from "react-icons/tb";
import SideBarMenu from "./components/SideBarMenu";
import SideBarItem from "./components/SideBarItem";
import { MdAddAPhoto } from "react-icons/md";
import { HiUserGroup } from "react-icons/hi";
import { TfiLayoutSlider } from "react-icons/tfi";


const AdminLayout = ({ children, sideBar }) => {
  //set current index
  const [currentIndex, setCurrentIndex] = useState(null);
  //set menu collapsed
  const [collapse, setCollapse] = useState(false);
  //set toggle menu collapsed
  const toggleCollapseSidebar = () => {
    setCollapse((collapse) => !collapse);
  };

  return (
    <div className="w-full flex flex-col justify-center items-center bg-stone-200">
      <Header onToggleMenu={toggleCollapseSidebar} logo="/assets/images/logo/logo.png"/>
      <main className="w-full flex justify-center items-start gap-3">
        {sideBar ? (
          sideBar
        ) : (
          <SideBar
            collapse={collapse}
            onOpenSidebar={toggleCollapseSidebar}
            title="Admin Panel"
          >
            <Accordion>
              <AccordionItem
                title="User"
                index={1}
                currentIndex={currentIndex}
                onOpen={setCurrentIndex}
                collapsed={collapse}
                Icon={
                  <FaUserPlus className="text-4xl cursor-pointer text-left" />
                }
              >
              <SideBarMenu>
                <SideBarItem link="" title="Add Role"/>
                <SideBarItem link="" title="Add Permission"/>
              </SideBarMenu>
              </AccordionItem>
            </Accordion>
            <Accordion>
              <AccordionItem
                title="Website"
                index={2}
                currentIndex={currentIndex}
                onOpen={setCurrentIndex}
                collapsed={collapse}
                Icon={
                  <TbWorldWww className="text-4xl cursor-pointer text-left" />
                }
              >
              <SideBarMenu>
                <SideBarItem link="" title="Add logo"/>
              </SideBarMenu>
              </AccordionItem>
            </Accordion>
            <Accordion>
              <AccordionItem
                title="Model"
                index={3}
                currentIndex={currentIndex}
                onOpen={setCurrentIndex}
                collapsed={collapse}
                Icon={
                  <HiUserGroup className="text-4xl cursor-pointer text-left" />
                }
              >
                <SideBarMenu>
                  <SideBarItem link="/admin/model/add" title="ADD MODEL"/>
                  <SideBarItem link="/admin/model/list" title="LIST MODEL"/>
                </SideBarMenu>
              </AccordionItem>
            </Accordion>
            <Accordion>
              <AccordionItem
                title="Model Photo"
                index={4}
                currentIndex={currentIndex}
                onOpen={setCurrentIndex}
                collapsed={collapse}
                Icon={
                  <MdAddAPhoto className="text-4xl cursor-pointer text-left" />
                }
              >
                <SideBarMenu>
                  <SideBarItem link="/admin/model-photo/add" title="ADD MODEL PHOTO"/>
                  <SideBarItem link="/admin/model-photo/list" title="LIST MODEL PHOTOS"/>
                </SideBarMenu>
              </AccordionItem>
            </Accordion>
            <Accordion>
              <AccordionItem
                title="Slider Image"
                index={5}
                currentIndex={currentIndex}
                onOpen={setCurrentIndex}
                collapsed={collapse}
                Icon={
                  <TfiLayoutSlider className="text-4xl cursor-pointer text-left" />
                }
              >
                <SideBarMenu>
                  <SideBarItem link="/admin/slider/add" title="ADD SLIDER PHOTO"/>
                  <SideBarItem link="/admin/slider/list" title="LIST SLIDER PHOTOS"/>
                </SideBarMenu>
              </AccordionItem>
            </Accordion>
          </SideBar>
        )}
        {children}
      </main>
      <Footer />
    </div>
  );
};

export default AdminLayout;
