import React, { useEffect, useRef } from "react";
import gsap from "gsap";
import classes from "./welcomeloader.module.css";
const WelcomeLoader = () => {
    
  const preloaderRef = useRef(null);
  const textRefs = useRef([]);

  useEffect(() => {
    const preloader = preloaderRef.current;

    textRefs.current.forEach((char, i) => {
      gsap.fromTo(
        char,
        { opacity: 0, y: 20 },
        {
          opacity: 1,
          y: 0,
          duration: 1,
          ease: "power3.inOut",
          delay: i * 0.1,
          repeat: -1,
          yoyo: true,
        }
      );
    });

    gsap.to(preloader, {
      duration: 1,
      opacity: 0,
      delay: 5, // Adjust the delay based on your actual loading time
      ease: "power3.inOut",
      onComplete: () => {
        preloader.style.display = "none";
      },
    });
  }, []);

  const text = "Worth Models";

  return (
    <div ref={preloaderRef} style={styles.preloader}>
      <div className={classes.textContainer}>
        {text.split("").map((char, index) => (
          <span
            key={index}
            ref={(el) => (textRefs.current[index] = el)}
            className={classes.char}
          >
            {char}
          </span>
        ))}
      </div>
    </div>
  );
};

const styles = {
  preloader: {
    position: "fixed",
    top: 0,
    left: 0,
    width: "100%",
    height: "100%",
    display: "flex",
    justifyContent: "center",
    alignItems: "center",
    backgroundColor: "#fff",
    zIndex: 9999,
  },
};

export default WelcomeLoader;
