import React, { useEffect, useState } from "react";
import ModelCard from "./ModelCard";
import { useModelPhoto } from "@/hooks/modelPhoto";
import { toast } from "react-toastify";
import CircleLoader from "@/components/UI/loader/circle/CircleLoader";
import Button from "@/components/UI/button/Button";

const ListModelPhoto = () => {
  //use hook
  const { deleteModelPhoto, fetchAllModelPhotos } = useModelPhoto();
  //use state
  const [loading, setLoading] = useState(false);
  const [allModelPhotos, setAllModelPhotos] = useState([]);
  const [deleteModelPhotoSuccess, setDeleteModelPhotoSuccess] = useState(false);

  useEffect(() => {
    //note delete action
    if (deleteModelPhotoSuccess) {
      toast.success("Model Photo Deleted Successfully", {
        position: "top-center",
        autoClose: 5000,
      });
      setDeleteModelPhotoSuccess(false);
      setLoading(false);
    }

    fetchAllModelPhotos(setAllModelPhotos);

  }, [deleteModelPhotoSuccess]);

  return (
    <>
      {loading ? (
        <CircleLoader />
      ) : (
        <div class="w-full max-h-screen bg-white flex flex-col justify-start items-center relative overflow-y-scroll scroll-smooth my-5 gap-4">
          <h2 className="text-center text-black py-4 font-textImpact">
            MODEL PHOTO LIST
          </h2>
          <a href="/admin/model-photo/add">
            {" "}
            <Button text="ADD MODEL PHOTO" />
          </a>
          <div className="w-full h-full flex flex-col justify-center items-center">
            {allModelPhotos &&
              allModelPhotos.length > 0 &&
              allModelPhotos.map((model) => {
                const { name, images } = model;
                return (
                  <div className="w-full flex flex-col justify-center items-center gap-2">
                    <h4 className="w-full text-2xl font-textImpact bg-indigo-800 my-5 p-4 text-white text-center">{model.name}</h4>
                    <div className="w-full h-full grid grid-cols-[300px_300px_300px_300px] grid-rows-auto gap-1 justify-center items-center">
                      {images.length > 0 &&
                        images.map((image) => (
                          <ModelCard
                            ImgSrc={image.image_url}
                            onDelete={() =>
                              deleteModelPhoto({
                                model_id: image.model_id,
                                image_id: image.id,
                                setLoading,
                                setDeleteModelPhotoSuccess,
                              })
                            }
                          />
                        ))}
                    </div>
                  </div>
                );
              })}
          </div>
        </div>
      )}
    </>
  );
};

export default ListModelPhoto;
