import React, { useState, useEffect } from "react";
import InputField from "@/components/UI/input/InputField";
import Button from "@/components/UI/button/Button";
import { useSliderImage } from "@/hooks/slider";
import CircleLoader from "@/components/UI/loader/circle/CircleLoader";
const AddSliderImage = () => {
  //use hook
  const { addSliderPhoto } = useSliderImage();
  //set loading state
  const [loading, setLoading] = useState(false);
  //set url
  const [url, setUrl] = useState(null);
  //set all input fields
  const [inputs, setInputs] = useState({
    title:'',
    image: null,
  });
  // InputValidationErrors
  const [validationErrors, setValidationErrors] = useState({});
  //define errors
  const [errors, setErrors] = useState([]);
  //handleInputChange
  const handleInputChange = (e) => {
    setInputs({ ...inputs, [e.target.name]: e.target.value });
  };
  //handle uploadFileChange
  const handleUploadFileChange = (e) => {
    // Get the selected file (only one file)
    const file = e.target.files[0];
    // this gives us the data on what files are selected
    if (file) {
      console.log("[file]", file);
      // transform files into data urls
      const url = URL.createObjectURL(file);
      //set image url
      setUrl(url);
      //set image url in state
      setInputs({ ...inputs, [e.target.name]: file });
    }
  };
  //check input validation
  const validate = (inputValues) => {
    const errors = {};
    const usernameRegex = /^[A-Za-z0-9]{3,16}$/;
    const emailRegex =
      /^(([^<>()[\]\.,;:\s@\"]+(\.[^<>()[\]\.,;:\s@\"]+)*)|(\".+\"))@(([^<>()[\]\.,;:\s@\"]+\.)+[^<>()[\]\.,;:\s@\"]{2,})$/i;
    if (!inputValues.image) {
      errors.image = "Model Slider Photo is required";
    }
    return errors;
  };
  //check validation error object
  const isObjectEmpty = (objectName) => {
    return (
      objectName &&
      Object.keys(objectName).length === 0 &&
      objectName.constructor === Object
    );
  };
  //submit the data in backend
  const handleSubmit = (event) => {
    //event is an event object
    event.preventDefault();
    //client-side validation
    const errors = validate(inputs);
    //set validation error in state object
    setValidationErrors(errors);
    if (!isObjectEmpty(errors)) {
      //if any errors occur return null and do not submit the input values
      return;
    } else {
      const { title, image } = inputs;
      // here you calling your submit api
      addSliderPhoto({
        setLoading,
        setErrors,
        setInputs,
        image,
        title
      });

      //dispatch action when you use redux
    }
  };
  return (
    <>
      {loading ? (
        <CircleLoader />
      ) : (
        <div className="w-full bg-white p-4 flex flex-col justify-center items-center rounded-md mt-10 gap-5">
          <h2 className="font-textImpact text-center">ADD SLIDER IMAGE</h2>
          <form
            className="w-[85%] flex flex-col justify-center items-center gap-3"
            onSubmit={handleSubmit}
          >
           <div className="w-11/12 grid grid-cols-12 justify-center items-center">
              <div className="col-span-6">
                <InputField
                  type="text"
                  name="title"
                  placeholder="Slider Title"
                  value={inputs.title}
                  onChange={handleInputChange}
                  className="w-11/12 bg-gray-200 rounded-full p-3 placeholder:text-black placeholder:font-title placeholder:font-semibold drop-shadow-md"
                  errorMessage={validationErrors["title"]}
                />
              </div>
              <div className="col-span-6">
               
              </div>
            </div>
            <div className="w-11/12 grid grid-cols-12 justify-center items-center">
              <div className="col-span-6">
                <InputField
                  type="file"
                  name="image"
                  className="w-11/12 bg-gray-200 rounded-full p-3 placeholder:text-black placeholder:font-title placeholder:font-semibold drop-shadow-md"
                  onChange={handleUploadFileChange}
                  errorMessage={validationErrors["image"]}
                />
              </div>
              <div className="col-span-6">
                <div className="relative w-[85%] h-[300px] m-5">
                  <img
                    src={url}
                    className="absolute w-full h-full object-contain"
                  />
                </div>
              </div>
            </div>
            <Button text="ADD SLIDER IMAGE" />
          </form>
        </div>
      )}
    </>
  );
};

export default AddSliderImage;
